# Project synopsis

## Project title
Using Monte Carlo Tree Search for playing the imperfect information card game Regicide 

## Project statement
This project aims to understand and train a Monte Carlo Tree Search algorithm to play the popular card game Regicide. In doing so a framework for playing the game should be developed, that can be used in the future for reinforcement learning research. 

Specifically, the project should:

1. Present the concept of reinforcement learning
1. Account for the theoretical foundation of the Monte Carlo Tree Search algorithm
1. Explain the rules of the game Regicide
1. Present an implementation of a python framework for playing an imperfect information card game Regicide suitable for use in reinforcement learning
1. Explain the process of learning to play the card game Regicide using Monte Carlo Tree Search with the implemented framework 
1. Present the performance of the learned Monte Carlo Tree Search model
1. Discuss the differences and challenges of learning perfect and imperfect information games
